#!/usr/bin/python

import sys

from charmhelpers.core.hookenv import (
    Hooks,
    config,
    is_relation_made,
    log,
    ERROR,
    relation_ids,
    relation_get,
    relation_set,
    service_name,
    unit_get,
    UnregisteredHookError,
)

from charmhelpers.core.host import (
    restart_on_change,
)

from charmhelpers.fetch import (
    apt_install,
    apt_update,
    filter_installed_packages,
)

from charmhelpers.contrib.openstack.utils import (
    configure_installation_source,
    openstack_upgrade_available,
)


from charmhelpers.payload.execd import execd_preinstall

hooks = Hooks()

@hooks.hook()
def install():
	log('install hook')

@hooks.hook('config-changed')
def config_changed():
	log('config_changed hook')

@hooks.hook('amqp-relation-joined')
def amqp_joined(relation_id=None):
	log('amqp joined')

@hooks.hook('amqp-relation-changed')
@hooks.hook('amqp-relation-departed')	
def amqp_changed():
	log('amqp changed')

@hooks.hook('shared-db-relation-joined')
def db_joined(rid=None):
	log('db joined')

@hooks.hook('pgsql-db-relation-joined')	
def pgsql_db_joined():
	log('pgsql_db_joined')

@hooks.hook('shared-db-relation-changed')
def db_changed():
	log('db_changed')

@hooks.hook('pgsql-db-relation-changed')	
def postgresql_db_changed():
	log('postgresql db changed')

@hooks.hook('image-service-relation-changed')	
def image_service_changed():
	log('image service changed')

@hooks.hook('cloud-compute-relation-joined')	
def compute_joined(rid=None):
	log('compute joined')

@hooks.hook('cloud-compute-relation-changed')	
def compute_changed():
	log('compute changed')

@hooks.hook('amqp-relation-broken',
            'ceph-relation-broken',
            'image-service-relation-broken',
            'shared-db-relation-broken',
            'pgsql-db-relation-broken')		
def relation_broken():
	log('relation broken')

@hooks.hook('nova-ceilometer-relation-changed')
def nova_ceilometer_relation_changed():
	log('ceilometer changed')


def main():
    try:
        hooks.execute(sys.argv)
    except UnregisteredHookError as e:
        log('Unknown hook {} - skipping.'.format(e))


if __name__ == '__main__':
    main()
